:math:`1 \longleftrightarrow N \delta\left[k\right]`

:math:`\delta\left[n\right] \longleftrightarrow 1`

:math:`\delta\left[- m + n\right] \longleftrightarrow e^{- \frac{2 \mathrm{j} \pi k m}{N}}`

:math:`u\left[n\right] \longleftrightarrow N \delta\left[k\right]`

:math:`n u\left[n\right] \longleftrightarrow \sum_{n=0}^{N - 1} n e^{- \frac{2 \mathrm{j} \pi k n}{N}}`

:math:`\alpha^{- n} u\left[n\right] \longleftrightarrow \sum_{n=0}^{N - 1} \alpha^{- n} e^{- \frac{2 \mathrm{j} \pi k n}{N}}`

